nortimecourseqcpart: Time-course Metabolomic Study with dataset with QCSs.

View source: R/selecttimec_qcs.R

nortimecourseqcpartR Documentation

Time-course Metabolomic Study with dataset with QCSs.

Description

this function enables performance assessment of metabolomic data processing for time-course data (with quality control sample but without internal standard) using four criteria, and can scan the customized workflows selected by user and rank them based on their performances.

Usage

nortimecourseqcpart(fileName, selectedMethods)

Arguments

fileName

Allows the user to indicate the NAME of peak table resulted from PrepareInuputFiles() (default = null).

selectedMethods

Allows the user to indicate the NAME of the file containing the customized workflows selected by user. The file should be in a .csv format, and the exemplar files are provided in the NOREVA R package and available for download at https://idrblab.org/noreva/NOREVA_exampledata.zip).

Examples

library(NOREVA)
timec_qc_data <- PrepareInuputFiles(dataformat = 1,
rawdata = "Timecourse_with_QCS.csv")
nortimecourseqcpart(fileName = timec_qc_data,
selectedMethods = "selectedmethods.csv")

idrblab/NOREVA documentation built on April 17, 2025, 2:04 p.m.